givitiCalibrationBeltTable prints on the graphical area of the calibration
belt plot the table that summarizes the significant deviations from the
line of perfect calibration (i.e. the bisector of the I quadrant).
givitiCalibrationBeltTable(cb, tableStrings, grayLevels, xlim, ylim)givitiCalibrationBelt object, to be generated with
the function givitiCalibrationBelt.overBisString,underBisString,confLevelString,
neverString. The four strings of the list are printed instead of the
texts "Over the bisector"/"Under the bisector"/"Confidence level"/"NEVER"
in the table reporting the intersections of the calibration belt with
the bisector.c(0,1).